@@ -1,5 +1,5 @@
 /******************************************************************************
-    (c) 1998-2000 P.J. Caulfield               patrick@tykepenguin.cix.co.uk
+    (c) 1998-2000 Christine Caulfield               christine.caulfield@googlemail.com
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -411,6 +411,7 @@ int send_smail(int sock,
 	    fprintf(mailpipe, "Mime-Version: 1.0\n");
 	    fprintf(mailpipe, "Content-Type: application/octet-stream\n");
 	    fprintf(mailpipe, "Content-Transfer-Encoding: base64\n");
+	    fprintf(mailpipe, "Content-Disposition: inline\n");
 	}
 	fprintf(mailpipe, "X-VMSmail: %s\n", full_user);
 
@@ -561,6 +562,9 @@ int send_body(int dnsock, FILE *unixfile)
 	do
 	{
 	    stat = read(dnsock, buf, sizeof(buf));
+            if (stat == -1 && errno == EINTR)
+                continue;
+
 	    if (stat == -1 && errno != ENOTCONN)
 	    {
 		DNETLOG((LOG_ERR, "Error reading message text: %m\n"));
