@@ -1,5 +1,5 @@
 /******************************************************************************
-    (c) 1999 P.J. Caulfield               patrick@tykepenguin.cix.co.uk
+    (c) 1999 Christine Caulfield               christine.caulfield@googlemail.com
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -395,7 +395,7 @@ void accept_decnet(int entry)
 {
     int newsock;
     struct sockaddr_dn sockaddr;
-    int len=sizeof(sockaddr);
+    socklen_t len=sizeof(sockaddr);
     
     if ( (newsock=accept(fdarray[entry].fd, (struct sockaddr *)&sockaddr, &len)) < 0)
     {
@@ -412,7 +412,7 @@ void accept_unix(int entry)
 {
     int newsock;
     struct sockaddr_un sockaddr;
-    int len=sizeof(sockaddr);
+    socklen_t len=sizeof(sockaddr);
     
     if ( (newsock=accept(fdarray[entry].fd, (struct sockaddr *)&sockaddr, &len)) < 0)
     {
